import * as ts from 'typescript';
import typescript from 'rollup-plugin-typescript2';
import builtins from 'rollup-plugin-node-builtins';
import commonjs from 'rollup-plugin-commonjs';
import resolve from 'rollup-plugin-node-resolve';
import uglify from 'rollup-plugin-uglify';
import json from 'rollup-plugin-json';
import replace from 'rollup-plugin-replace';
import globals from 'rollup-plugin-node-globals';
import alias from 'rollup-plugin-alias';

import pkg from './package.json';

const basicOptions = {
  input: './index.ts',

  context: 'window',

  plugins: [
    typescript({
      typescript: ts,
      useTsconfigDeclarationDir: true,
    }),
    json(),
    commonjs({}),
    replace({
      'process.env.NODE_ENV': JSON.stringify('production'),
    }),
  ],
};

const umdOptions = {
  ...basicOptions,
  output: [
    {
      format: 'umd',
      name: 'BuilderHtml2Canvas',
      file: 'dist/index.umd.js',
      amd: {
        id: '@builder.io/editor-client',
      },
    },
  ],
  plugins: basicOptions.plugins.concat([resolve()]),
};

const umdMinOptions = {
  ...basicOptions,
  output: [
    {
      format: 'umd',
      name: 'BuilderHtml2Canvas',
      file: pkg.browser,
      amd: {
        id: '@builder.io/editor-client',
      },
    },
  ],
  plugins: basicOptions.plugins.concat([resolve(), uglify()]),
};

const externalModuleOptions = {
  ...basicOptions,
  output: [
    {
      format: 'cjs',
      file: pkg.main,
    },
    {
      format: 'es',
      file: pkg.module,
    },
  ],
  external: Object.keys(pkg.dependencies),
  plugins: basicOptions.plugins.concat([
    resolve({
      only: [/^\.{0,2}\//],
    }),
  ]),
};

const browserOptions = {
  ...basicOptions,
  output: [{ file: pkg.unpkg, format: 'iife', name: 'BuilderHtml2Canvas', sourcemap: true }],
  plugins: basicOptions.plugins.concat([resolve(), uglify()]),
};

export default [umdOptions, umdMinOptions, externalModuleOptions, browserOptions];
